PySDL3 Documentation
====================
PySDL3 is a pure Python wrapper around the SDL3, SDL3_image, SDL3_mixer, SDL3_ttf, SDL3_rtf and SDL3_net libraries.
It uses the built-in ctypes library to interface with SDL3 while providing an **understandable**
function definition with docstrings, argument names and type hints, like this:

.. image:: ../res/snippet.png

Getting Started
===============

.. toctree::
  :maxdepth: 2

  install.rst